==> botorch-0.7.0.tar.gz: botorch-0.7.0/botorch/models/__init__.py <==
#!/usr/bin/env python3
# Copyright (c) Meta Platforms, Inc. and affiliates.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

from botorch.models.approximate_gp import (
    ApproximateGPyTorchModel,
    SingleTaskVariationalGP,
)
from botorch.models.cost import AffineFidelityCostModel
from botorch.models.deterministic import (
    AffineDeterministicModel,
    GenericDeterministicModel,
    PosteriorMeanModel,
)
from botorch.models.fully_bayesian import SaasFullyBayesianSingleTaskGP
from botorch.models.gp_regression import (
    FixedNoiseGP,
    HeteroskedasticSingleTaskGP,
    SingleTaskGP,
)
from botorch.models.gp_regression_fidelity import SingleTaskMultiFidelityGP
from botorch.models.gp_regression_mixed import MixedSingleTaskGP
from botorch.models.higher_order_gp import HigherOrderGP
from botorch.models.model import ModelList
from botorch.models.model_list_gp_regression import ModelListGP
from botorch.models.multitask import (
    FixedNoiseMultiTaskGP,
    KroneckerMultiTaskGP,
    MultiTaskGP,
)
from botorch.models.pairwise_gp import PairwiseGP, PairwiseLaplaceMarginalLogLikelihood

__all__ = [
    "AffineDeterministicModel",
    "AffineFidelityCostModel",
    "ApproximateGPyTorchModel",
    "FixedNoiseGP",
    "FixedNoiseMultiTaskGP",
    "SaasFullyBayesianSingleTaskGP",
    "GenericDeterministicModel",
    "HeteroskedasticSingleTaskGP",
    "HigherOrderGP",
    "KroneckerMultiTaskGP",
    "MixedSingleTaskGP",
    "ModelList",
    "ModelListGP",
    "MultiTaskGP",
    "PairwiseGP",
    "PairwiseLaplaceMarginalLogLikelihood",
    "PosteriorMeanModel",
    "SingleTaskGP",
    "SingleTaskMultiFidelityGP",
    "SingleTaskVariationalGP",
]

==> botorch-0.15.0.tar.gz: botorch-0.15.0/botorch/models/__init__.py <==
#!/usr/bin/env python3
# Copyright (c) Meta Platforms, Inc. and affiliates.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

from botorch.models.approximate_gp import (
    ApproximateGPyTorchModel,
    SingleTaskVariationalGP,
)
from botorch.models.cost import AffineFidelityCostModel
from botorch.models.deterministic import (
    AffineDeterministicModel,
    GenericDeterministicModel,
    PosteriorMeanModel,
)
from botorch.models.fully_bayesian import SaasFullyBayesianSingleTaskGP
from botorch.models.fully_bayesian_multitask import SaasFullyBayesianMultiTaskGP

from botorch.models.gp_regression import SingleTaskGP
from botorch.models.gp_regression_fidelity import SingleTaskMultiFidelityGP
from botorch.models.gp_regression_mixed import MixedSingleTaskGP
from botorch.models.higher_order_gp import HigherOrderGP

from botorch.models.map_saas import add_saas_prior, AdditiveMapSaasSingleTaskGP
from botorch.models.model import ModelList
from botorch.models.model_list_gp_regression import ModelListGP
from botorch.models.multitask import KroneckerMultiTaskGP, MultiTaskGP
from botorch.models.pairwise_gp import PairwiseGP, PairwiseLaplaceMarginalLogLikelihood

__all__ = [
    "add_saas_prior",
    "AdditiveMapSaasSingleTaskGP",
    "AffineDeterministicModel",
    "AffineFidelityCostModel",
    "ApproximateGPyTorchModel",
    "SaasFullyBayesianSingleTaskGP",
    "SaasFullyBayesianMultiTaskGP",
    "GenericDeterministicModel",
    "HigherOrderGP",
    "KroneckerMultiTaskGP",
    "MixedSingleTaskGP",
    "ModelList",
    "ModelListGP",
    "MultiTaskGP",
    "PairwiseGP",
    "PairwiseLaplaceMarginalLogLikelihood",
    "PosteriorMeanModel",
    "SingleTaskGP",
    "SingleTaskMultiFidelityGP",
    "SingleTaskVariationalGP",
]
